/** BEGIN COPYRIGHT BLOCK
 * Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
 * Copyright (C) 2005 Red Hat, Inc.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * END COPYRIGHT BLOCK **/
/*///////////////////////////////////////////////////////*/
/*/                                                     /*/
/*/ David Tompkins (mailto:dt@netscape.com)             /*/
/*/ Netscape Communications Corp.                       /*/
/*/ 9/21/98                                             /*/
/*/                                                     /*/
/*/ start_config_ds: starts a config DS instance        /*/
/*/                                                     /*/
/*///////////////////////////////////////////////////////*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifdef XP_UNIX
#   define FILE_SEP '/'
#   define STRNCASECMP strncasecmp
#   define SLEEP sleep
#   include <unistd.h>
#else /* XP_WIN32 */
#   define FILE_SEP '/'
#   define STRNCASECMP _strnicmp
#   define SLEEP _sleep
#endif

#define PATH_LENGTH       1024
#define ADMIN_CONFIG_FILE "adm.conf"
#define COMMENT_CHAR      '#'
#define LDAP_START_KEY    "ldapStart"

void
error(char *msg)
{
   printf("StartConfigDS Error: %s\n", msg);
}

int
error_exit(char *msg)
{
   printf("Content-type: text/html\n\n");
   printf("<title>StartConfigDS Error</title><h1>StartConfigDS Error</h1>");
   printf("Your request could not be fulfilled.<br><br>");
   printf("<b>Reason :</b> %s<br>", msg);
   exit(0) ;
}

int
success_exit()
{
   SLEEP(10);
   printf("Content-type: text/html\n");
   printf("Content-length: 13\n\n");
   printf("NMC_Status: 0");
   fflush(stdout);
   fclose(stdout);
   exit(0) ;
}

static char *
caseless_strstr(char *string, char *pattern)
{
   char *p;

   if (!string || !pattern)
      return (NULL);

   for (p = string ; *p ; p++)
   {
      if (!STRNCASECMP(p, pattern, strlen(pattern)))
	 return (p);
   }

   return (NULL);
}

int
main(int argc, char *argv[])
{
   char  path[PATH_LENGTH], line[PATH_LENGTH];
   char *admroot    = NULL;
   char *srvroot    = NULL;
   FILE *configfile = NULL;
   char *p;
   int   ret_val;

   /* find and open the AS config file adm.conf */

   if (!(admroot = getenv("ADMSERV_ROOT")))
      return error_exit("ADMSERV_ROOT not found");

   if (!(srvroot = getenv("NETSITE_ROOT")))
      return error_exit("NETSITE_ROOT not found");

   snprintf(path, sizeof(path), "%s%c%s", admroot, FILE_SEP, ADMIN_CONFIG_FILE);
   path[sizeof(path)-1] = 0;

   if (!(configfile = fopen(path, "r")))
      return error_exit("Failed to open adm.conf");

   /* look for config DS start executable path */

   while (fgets(line, PATH_LENGTH, configfile))
   {
      if (line[0] == COMMENT_CHAR)
	 continue;
      
      if (STRNCASECMP(line, LDAP_START_KEY, strlen(LDAP_START_KEY)))
	 continue;

      /* found. chew whitespace, build full executable path and execute. */

      p  = line;
      p += strlen(LDAP_START_KEY);
      while (*p != ':')
	 p++;
      p++;
      while ((*p == ' ') || (*p == '\t'))
	 p++;

      snprintf(path, sizeof(path), "%s%c%s", srvroot, FILE_SEP, p);
      path[sizeof(path)-1] = 0;
      
      /* this should probably be an explicit fork/exec, but I don't have the time... */
      if ((ret_val = system(path)) == -1)
         return error_exit("system() returned -1");

      if (ret_val != 0)
	 return error_exit("Execution of the StartConfigDS command returned non-zero");

      return success_exit(); 
   }

   return error_exit("No ldapStart entry found in adm.conf");
}
