#
# BEGIN COPYRIGHT BLOCK
# Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
# Copyright (C) 2005 Red Hat, Inc.
# All rights reserved.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

# END COPYRIGHT BLOCK
#
# This is the default target for all Makefiles which include this file.
# Those Makefiles should define this target with the appropriate dependencies
# and build rules.
#
all:

ABS_ROOT := $(shell cd $(BUILD_ROOT)/..; pwd)
NSROOT = $(BUILD_ROOT)

ifdef INTERNAL_BUILD
# the directory containing pre-built binary components for use during
# building and packaging, including Red Hat branded components
COMPONENTS_DIR = /share/builds/components
INT_DIR = /share/builds/sbsintegration
# these are Fedora branded components - only a few components are branded
FED_COMPONENTS_DIR = /fedora/components
else
# just set these by default
GET_JAVA_FROM_PATH := 1
GET_ANT_FROM_PATH := 1
endif

include $(NSROOT)/nsdefs.mk

NSOS_TEST1       := $(shell uname -m)

ifneq (x86_64, $(NSOS_TEST1))
  ifeq (86, $(findstring 86, $(NSOS_TEST1)))
    CPU_ARCH := x86
  else 
    CPU_ARCH := $(NSOS_TEST1)
  endif
else
  CPU_ARCH := $(NSOS_TEST1)
endif

ifeq ($(NSOS_TEST1),i86pc)
  NSCONFIG         = $(NSPLATFORM_DIR)
else
  ifeq ($(NSOS_ARCH), Linux)
    ifeq ($(USE_LIBC), 1)
      NSCONFIG         = $(NSPLATFORM_DIR)_$(CPU_ARCH)_libc
    else
      NSCONFIG         = $(NSPLATFORM_DIR)_$(CPU_ARCH)_glibc
    endif
  else
    ifeq ($(NSOS_ARCH),RHEL)
      NSCONFIG        = $(NSOS_ARCH)$(NSOS_RELEASE)_$(CPU_ARCH)_$(GCC_VERSION)
    else
      NSCONFIG         = $(NSPLATFORM_DIR)
    endif
  endif
endif

ifeq ($(NSOS_ARCH),WINNT)
  ifeq ($(DEBUG), fulld)
   NSOBJDIR_NAME     = $(NSCONFIG)$(NSOBJDIR_TAG).OBJD
  else
   NSOBJDIR_NAME     = $(NSCONFIG)$(NSOBJDIR_TAG).OBJ
  endif
else
ifeq ($(NSOS_ARCH),RHEL)
  NSOBJDIR_NAME = $(NSCONFIG)$(NSOBJDIR_TAG).OBJ
else
 ifeq ($(USE_PTHREADS), 1)
   ifeq ($(USE_N32), 1)
      NSOBJDIR_NAME     = $(NSCONFIG)_n32_PTH$(NSOBJDIR_TAG).OBJ
   else  
      NSOBJDIR_NAME     = $(NSCONFIG)_PTH$(NSOBJDIR_TAG).OBJ
   endif
 else
  NSOBJDIR_NAME     = $(NSCONFIG)$(NSOBJDIR_TAG).OBJ
 endif
endif
endif

# Destination for class files and packages
CLASS_DEST=$(ABS_ROOT)/dist/classes

# NSPR build stuff
NSCP_DIST			  = $(BUILD_ROOT)/../dist
NSCP_DISTDIR          = $(NSCP_DIST)/$(NSOBJDIR_NAME)

MAKE=gmake $(BUILDOPT) NO_MOCHA=1 NO_JAVA=1 NSPR_BASENAME=$(NSPR_BASENAME) USE_PTHREADS=$(USE_PTHREADS) SECURITY=$(SECURITY) BUILD_MODE=$(BUILD_MODE)

export NSPR20=1

NSDEFS=SERVER_BUILD=1 XCFLAGS=$(MCL_CFLAGS) USE_PTHREADS=$(USE_PTHREADS) \
       NS_PRODUCT=$(NS_PRODUCT) VERSION=$(SERVER_VERSION) \
       NS_USE_NATIVE=$(NS_USE_NATIVE) NSPR_BASENAME=$(NSPR_BASENAME)

NSPR_DEFINES = -DSERVER_BUILD

# ------------------------ Product-specific flags ------------------------


ifeq ($(PRODUCT), "Fedora SuiteSpot Common Installer")
MCC_SERVER=
endif

ifeq ($(PRODUCT), "Fedora Administration Server")
ifeq ($(SECURITY), export)
MCC_SERVER=-DMCC_HTTPD -DMCC_ADMSERV -DNS_EXPORT -DNET_SSL -DCLIENT_AUTH $(NSPR_DEFINES)
endif
ifeq ($(SECURITY), domestic)
MCC_SERVER=-DMCC_HTTPD -DMCC_ADMSERV -DNS_DOMESTIC -DNET_SSL -DCLIENT_AUTH $(NSPR_DEFINES)
endif
ifeq ($(SECURITY), none)
MCC_SERVER=-DMCC_HTTPD -DMCC_ADMSERV -DNS_UNSECURE $(NSPR_DEFINES)
endif
endif

ifeq ($(BUILD_MODULE), SETUP_ADMIN)
MCC_SERVER=-DMCC_ADMSERV
NS_PRODUCT = MCC_ADMSERV
endif

ifeq ($(BUILD_MODULE), UNINST_SHELL)
MCC_SERVER=-DMCC_ADMSERV
endif

ifeq ($(BUILD_MODULE), UNINST_ADMIN)
MCC_SERVER=-DMCC_HTTPD -DMCC_ADMSERV
endif


MCC_SERVER += -DSPAPI20 -DBUILD_NUM=$(GET_BUILD_NUM)

# ----------- Default Flags, may be overridden below ------------

CPPCMD=$(CC) -E
HTTPDSO_NAME=ns-httpd
MATHLIB=-lm
LIB_SUFFIX=a
AR=ar rcv $@
DLL_PRESUF=
DLL_SUFFIX=so
LDAP_DLL_PRESUF=
LDAP_DLL_SUFFIX=$(DLL_SUFFIX)
LINK_DLL=ld $(DLL_LDFLAGS) -o $@
LINK_PLUGIN=$(LINK_DLL)

# ---------------------- OS-specific compile flags -----------------------


#-------------------
ifeq ($(ARCH), AIX)
#-------------------
DLL_PRESUF=
DLL_SUFFIX=so
#LDAP_DLL_PRESUF=_shr
LDAP_DLL_PRESUF=
LDAP_DLL_SUFFIX=so
ifeq ($(NSOS_RELEASE), 4.3)
AIX4_3=-D AIX4_3
endif
ifeq ($(USE_64), 1)
OBJECT_MODE=64 
export OBJECT_MODE 
endif
CC=xlC_r -qarch=com -DAIX -DAIXV3 -DAIXV4 -DSYSV $(AIX4_3)
CXX=$(CC)
CCC=$(CC)
CPPCMD=/usr/ccs/lib/cpp -P
ARCH_DEBUG=-g
ARCH_OPT=-O
RANLIB=ranlib
NONSHARED_FLAG=-bnso -bI:/lib/syscalls.exp
EXPORT_FILE=$*.exp
DEF_LIBPATH=/usr/lib/threads:/usr/lpp/xlC/lib:/usr/lib:/lib
MKSHLIB_FLAGS=-p 0 -blibpath:$(DEF_LIBPATH)
DLL_LDFLAGS=-bM:SRE -bnoentry -blibpath:$(DEF_LIBPATH)
# AIX plugins can have unresolved references
LINK_PLUGIN+=-berok
LINK_DLL=$(ABS_ROOT)/build/aixmkshlib -o $@ $(MKSHLIB_FLAGS)
MKSHLIB=$(LINK_DLL)
EXTRA_LIBS=-ldl

VERITY_ARCH=_rs6k41
NSAPI_CAPABLE=true
USE_PTHREADS=0
DL_LIB =-lsvld
NSPR_DEFINES += -DNSPR20
RWTOOLS_VERSION = latest
HTTPDSO_NAME=libnshttpd
PEER_ARCH=aix

else
#-------------------
ifeq ($(ARCH), HPUX)
#-------------------
HPUX_ARCH = $(shell uname -m)
ifeq ($(HPUX_ARCH), ia64)
    DLL_SUFFIX=so
else
    DLL_SUFFIX=sl
endif
LDAP_DLL_SUFFIX=$(DLL_SUFFIX)

ifeq ($(NSOS_RELEASE), B.11.00)
MODERNHP=1
endif
ifeq ($(NSOS_RELEASE), B.11.11)
MODERNHP=1
endif
ifeq ($(NSOS_RELEASE), B.11.23)
    MODERNHP=1
endif

ifeq ($(MODERNHP), 1)
CXX=/opt/aCC/bin/aCC
CC=cc -Ae
ifeq ($(NSOS_RELEASE), B.11.23)
  CC+=+Olit=all
  ifeq ($(USE_64), 1)
    BIT_SWITCH=+DD64
  else
    BIT_SWITCH=+DD32
  endif
  IPF_CFLAGS=-DPIC
  EXTRA_LIBS= -ldld -lm -lpthread
else # 11.11 or earlier
  CC+=+ESlit
  ifeq ($(USE_64), 1)
    BIT_SWITCH=+DA2.0W +DS2.0 -DHPUX_64 -Wl,+s
  else
    BIT_SWITCH=+DAportable +DS1.1 -Wl,+s
  endif
  IPF_CFLAGS=
  EXTRA_LIBS= -ldld -lm -lpthread
endif # B.11.23
ARCH_CFLAGS=$(BIT_SWITCH) -D_HPUX_SOURCE -D_POSIX_C_SOURCE=199506L -D__STDC_EXT__ +z -DHPUX11 $(IPF_CFLAGS)
else
CC=cc
ARCH_CFLAGS=-D_HPUX_SOURCE -Aa +DA1.0 +z
EXTRA_LIBS= -ldld -lm -ldce
endif

CCC=$(CXX)

ARCH_DEBUG=-g
ARCH_OPT=-O

RANLIB=true
NONSHARED_FLAG=-Wl,-a,archive

#
# Flags passed to CC to pass onto the linker; separate it from EXTRA_LIBS
LD_CFLAGS=-Wl,-E $(BIT_SWITCH)
DLL_CFLAGS=+z
DLL_LDFLAGS=-b $(BIT_SWITCH)
MODULE_CFLAGS += $(BIT_SWITCH)
NSAPI_CAPABLE=true
VERITY_ARCH=_hp800
USE_PTHREADS=0
NSPR_DEFINES += -DNSPR20 -D_PR_NTHREAD -D_PR_USECPU -D_REENTRANT
LINK_DLL=$(CCC) $(DLL_LDFLAGS) -o $@
HTTPDSO_NAME=libnshttpd
PEER_ARCH=hp
RWTOOLS_VERSION = latest

else
#-------------------
ifeq ($(ARCH), Linux)
#-------------------
NS_USE_GCC	= 1
CC=gcc
CCC=g++
ARCH_DEBUG=-g
ARCH_OPT=-O2
ARCH_CFLAGS=-fPIC -pipe -DLINUX -Dlinux -DBSD -D_POSIX_SOURCE -D_XOPEN_SOURCE -D_BSD_SOURCE -DHAVE_STRERROR -DNO_DBM
USE_PTHREADS=1
NSPR_DEFINES += -DNSPR20 -Di386
RANLIB=ranlib
BUILD_IIOPLIB=no
ifeq ($(USE_PTHREADS), 1)
  NSPR_DEFINES         += -D_REENTRANT -D_PR_NEED_FAKE_POLL
endif
LINK_DLL=$(CC) -shared -Wl,-soname -Wl,$(@:$(OBJDIR)/%.so=%.so)
EXTRA_LIBS=-lpthread -lc -lresolv -ldl
PEER_ARCH=linux

BUILD_NMC=true

else
#-------------------
ifeq ($(ARCH), OSF1)
#-------------------
CC=cc
CCC=cxx
CXX=cxx
ARCH_DEBUG=-g
ARCH_OPT=-O2
ifeq ($(NSOS_OSF1REV),878)
  ARCH_CFLAGS=-DOSF1V4D -DIS_64 -ieee_with_inexact -pthread
else
  ARCH_CFLAGS=-DIS_64 -ieee_with_inexact -pthread
endif
# ranlib no longer needed on OSF1 V4.0
RANLIB=true
DLL_LDFLAGS=-shared -all -expect_unresolved "*"
NONSHARED_FLAG=-non_shared
NSAPI_CAPABLE=true
VERITY_ARCH=_aosf40
EXTRA_LIBS=
USE_PTHREADS=0
NSPR_DEFINES += -DNSPR20
RWTOOLS_VERSION = latest
ADM_RELDATE=19970605

export NO_DB2=1
export NO_ODBC=1

else
#----------------------
ifeq ($(ARCH), SOLARIS)
#----------------------

#
# 7/12/96 Adrian - Switch to use SparcWorks for 3.0 Development
#		   Therefore no need to separate from catalog server
#
OSVERSION := $(shell uname -r | sed "y/./0/")
NS_USE_NATIVE=1
CC=cc
CXX=CC
CCC=$(CXX)
ARCH_OPT=-xO2
ifeq ($(USE_64), 1)
BIT_SWITCH=-xarch=v9
CXX+= $(BIT_SWITCH)
endif
ARCH_CFLAGS=$(BIT_SWITCH) -KPIC -DSVR4 -D__svr4 -D__svr4__ -D_SVID_GETTOD -DOSVERSION=$(OSVERSION)
ARCH_DEBUG=-g
RANLIB=true

EXTRA_LIBS = -lthread -lposix4 -lsocket -lnsl -ldl -lresolv -lgen

ifeq ($(USE_FORTE6), 1)
EXTRA_LIBS := $(EXTRA_LIBS) -lCrun -lCstd
endif

DLL_LDFLAGS=-G
NONSHARED_FLAG=-static
NSAPI_CAPABLE=true
NLIST=-lelf
VERITY_ARCH=_solaris
NSPR_DEFINES += -DNSPR20 -D_PR_NTHREAD -D_REENTRANT
PEER_ARCH=solaris

BUILD_NMC=true

else
#-------------------------
ifeq ($(ARCH), SOLARISx86)
#-------------------------
OSVERSION := $(shell uname -r | sed "y/./0/")
NS_USE_NATIVE=1
# Add SOLARIS define as well as SOLARISx86 which happens automagically
CC=cc -DSOLARIS
CXX=CC -DSOLARIS
CCC=$(CXX)
ARCH_OPT=-xO2
ARCH_CFLAGS=-DSVR4 -D__svr4 -D__svr4__ -D_SVID_GETTOD -DOSVERSION=$(OSVERSION)
ARCH_DEBUG=-g
RANLIB=true

EXTRA_LIBS = -lsocket -lthread -lposix4 -lnsl -ldl -lresolv -lm

DLL_LDFLAGS=-G
LDAP_VERSION    = oem
RWTOOLS_VERSION = latest
ADM_RELDATE     = oem
AUTOCATALOG_VERSION = oem
NONSHARED_FLAG=-static
NSAPI_CAPABLE=true
NLIST=-lelf
NO_MSOFT_OBJ=1
BUILD_WEBPUB=no
BUILD_IIOPLIB=no
NSPR_DEFINES += -DNSPR20 -D_PR_NTHREAD -D_REENTRANT
export NO_INFORMIX=1
export NO_ORACLE=1
export NO_SYBASE=1
export NO_ODBC=1
export NO_DB2=1
PEER_ARCH=solarisx86

else
#-------------------
ifeq ($(ARCH), WINNT)
#-------------------
LIB_SUFFIX=lib
DLL_SUFFIX=dll
LDAP_DLL_SUFFIX=$(DLL_SUFFIX)
PROCESSOR := $(shell uname -p)
PEER_ARCH=nti31
ifeq ($(PROCESSOR), I386)
CPU_ARCH = x386
VERITY_ARCH=_nti31
ARCH_OPT=-DNDEBUG -O2
ifeq ($(DEBUG), fulld)
CC=cl -nologo -MDd -W3 -GT -GX -D_X86_ -Dx386 -DWIN32 -D_WINDOWS -D_RWTOOLSDLL
CCP=cl -nologo -MDd -W3 -GT -GX -D_X86_ -Dx386 -DWIN32 -D_WINDOWS -D_MBCS -D_AFXDLL -D_RWTOOLSDLL
else
CC=cl -nologo -MD -W3 -GT -GX -D_X86_ -Dx386 -DWIN32 -D_WINDOWS -D_RWTOOLSDLL
CCP=cl -nologo -MD -W3 -GT -GX -D_X86_ -Dx386 -DWIN32 -D_WINDOWS -D_MBCS -D_AFXDLL -D_RWTOOLSDLL
endif
BUILD_NMC=true

else
ifeq ($(PROCESSOR), MIPS)
CPU_ARCH = MIPS
VERITY_ARCH=verity_is_undefined
ARCH_OPT=-DNDEBUG -O2
CC=cl -nologo -MD -W3 -GT -GX -D_MIPS_ -DWIN32 -D_WINDOWS -D_RWTOOLSDLL
CCP=cl -nologo -MD -W3 -GT -GX -D_X86_ -Dx386 -DWIN32 -D_WINDOWS -D_MBCS -D_AFXDLL -D_RWTOOLSDLL
else
ifeq ($(PROCESSOR), ALPHA)
CPU_ARCH = ALPHA
VERITY_ARCH=_ant35
ARCH_OPT=-DNDEBUG -Od
CC=cl -nologo -MD -W3 -GT -GX -D_ALPHA=1 -DWIN32 -D_WINDOWS -D_RWTOOLSDLL
CCP=cl -nologo -MD -W3 -GT -GX -D_ALPHA_ -DWIN32 -D_WINDOWS -D_MBCS -D_AFXDLL -D_RWTOOLSDLL
BUILD_IIOPLIB=no
export NO_SYBASE=1
export NO_ODBC=1
export NO_DB2=1
else
CPU_ARCH = processor_is_undefined
endif
endif
endif

RC=rc $(MCC_SERVER)
MC=mc
ARCH_DEBUG=-D_DEBUG -Od	-Z7
ARCH_CFLAGS=
ARCH_LINK_DEBUG=-DEBUG
ARCH_LINK_OPT=
RANLIB=echo

EXTRA_LIBS=wsock32.lib kernel32.lib user32.lib gdi32.lib winspool.lib \
           comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib \
           rpcrt4.lib uuid.lib odbc32.lib odbccp32.lib winmm.lib

DLL_LDFLAGS=
NONSHARED_FLAG=
NSAPI_CAPABLE=true
NO_MSOFT_OBJ=1
NSPR_DEFINES += -DNSPR20 -D_PR_NTHREAD -D_PR_USECPU

else

CC=UNKNOWN_SYSTEM_TYPE

endif
endif
endif
endif
endif
endif
endif

# ------------------------ The actual build rules ------------------------


ifeq ($(DEBUG), full)
MCC_DEBUG=-DMCC_DEBUG $(ARCH_DEBUG)
NSOBJDIR_TAG=_DBG
ML_DEBUG=$(ARCH_LINK_DEBUG)

else
ifeq ($(DEBUG), fulld)
MCC_DEBUG=-DMCC_DEBUG $(ARCH_DEBUG)
NSOBJDIR_TAG=_DBG
ML_DEBUG=$(ARCH_LINK_DEBUG)

else
ifeq ($(DEBUG), purify)

MCC_DEBUG=$(ARCH_DEBUG)
NSOBJDIR_TAG=_DBG
ML_DEBUG=$(ARCH_LINK_DEBUG)
PUREOPTS=-follow-child-processes=true
PURIFY=purify $(PUREOPTS)

else
MCC_DEBUG=$(ARCH_OPT)
NSOBJDIR_TAG=_OPT
ML_DEBUG=$(ARCH_LINK_OPT)
BUILDOPT = BUILD_OPT=1
endif
endif
endif

ifeq ($(PRODUCT), "Fedora Administration Server")
ADM_VERSION =
else
ifndef ADM_RELDATE
ADM_RELDATE = 19970811
endif
ifeq ($(SECURITY), domestic)
ADM_VERSION = $(ADM_RELDATE)D
else
ADM_VERSION = $(ADM_RELDATE)E
endif
endif

ADM_SUF=1.0.3
ADM_GEN_SUF=1.0

# CLEAN THIS UP

RM=rm
DEPEND=makedepend
STRIP=strip

# AS INCLUDE DEFDINED HERE
MCC_INCLUDE=-I$(NSROOT)/include \
			-I$(NSCP_DISTDIR)/include \
			-I$(NSPR_INCLUDE) \
			-I$(SECURITY_INCLUDE) \
			-I$(ICU_INCLUDE) \
			-I$(LDAPSDK_INCLUDE) -I$(ADMINUTIL_INCLUDE)

ifeq ($(ARCH), WINNT)
XP_FLAG=-DXP_WIN32  -DXP_WIN -D_WINDOWS -DXP_PC -DXP_WINNT
else
XP_FLAG=-DXP_UNIX
endif
# CFLAGS_NO_ARCH is needed temporarily by NS_MAIL
CFLAGS_NO_ARCH=$(NODE_FLAG) $(BOMB) $(MODULE_CFLAGS) $(XP_FLAG) \
       -D$(ARCH) $(MCC_DEBUG) $(MCC_SERVER)
CFLAGS=$(ARCH_CFLAGS) $(CFLAGS_NO_ARCH)
ifeq ($(BUILD_DLL), yes)
CFLAGS += -DBUILD_DLL
endif
LFLAGS=$(ML_DEBUG)

ifeq ($(BSCINFO), yes)
CBSCFLAGS=-FR$(OBJDEST)/$*.sbr
endif

# These are the defaults, individual Makefiles can override them as necessary
FVERSION=$(MAJOR_VERSION).$(MINOR_VERSION)
FVERSION_FLAGS=-v$(FVERSION)

#$(NSROOT)/fversion.exe: $(NSROOT)/dategen/fversion.c
#	cl $< user32.lib -link -out:$@

ifeq ($(ARCH), WINNT)
$(OBJDEST)/%.res: %.rc 
	$(RC) -I$(DIRVERDIR) -Fo$@ $*.rc
endif

ifndef NOSTDCOMPILE
$(OBJDEST)/%.o: %.cpp
ifeq ($(ARCH), WINNT)
	$(CCP) -c $(CFLAGS) $(MCC_INCLUDE) $< -Fo$(OBJDEST)/$*.o
else
	$(CCC) -c $(CFLAGS) $(MCC_INCLUDE) $< -o $(OBJDEST)/$*.o
endif
endif

ifndef NOSTDCOMPILE
$(OBJDEST)/%.o: %.c
ifeq ($(ARCH), WINNT)
ifeq ($(BOUNDS_CHECKER), yes)
	bcompile -c -Zop $(NSROOT)/bchecker.ini -nologo -MD -W3 -GT -GX -DWIN32 \
	    -D_WINDOWS $(CFLAGS) $(MCC_INCLUDE) $< -Fo$(OBJDEST)/$*.o
else
	$(CC) -c $(CFLAGS) $(MCC_INCLUDE) $< -Fo$(OBJDEST)/$*.o $(CBSCFLAGS)
endif
else
	$(CC) -c $(CFLAGS) $(MCC_INCLUDE) $< -o $(OBJDEST)/$*.o
endif
endif

ifeq ($(ARCH), WINNT)
AR=lib /nologo /out:"$@"
LINK_SUBSYSTEM  = windows
LINK_DLL	= link /nologo /MAP /DLL /PDB:NONE $(ML_DEBUG) /SUBSYSTEM:WINDOWS $(LLFLAGS) $(DLL_LDFLAGS) /out:"$@"
LINK_EXE	= link -OUT:"$@" /MAP  $(ARCH_LINK_DEBUG) $(LCFLAGS) /NOLOGO /PDB:NONE /INCREMENTAL:NO \
                  /SUBSYSTEM:$(LINK_SUBSYSTEM) $(OBJS) $(DEPLIBS) $(EXTRA_LIBS)
BSCMAKE = bscmake.exe /nologo /o $@
endif # WINNT

#include $(NSROOT)/verity.mk

ifndef NOSTDCLEAN
clean:
	$(RM) -f .depends.$(NSOBJDIR_NAME)  $(LIBS) $(OBJDEST)/*.o *_pure_* $(BINS) $(PUREFILES)
endif

ifndef NOSTDDEPEND
ifeq ($(ARCH), WINNT)
INCLUDE_DEPENDS = $(NULL)
depend:
	echo making depends
else
INCLUDE_DEPENDS = .depends.$(NSOBJDIR_NAME)
.depends.$(NSOBJDIR_NAME):
	touch .depends.$(NSOBJDIR_NAME)

depend:
	$(DEPEND) -f.depends.$(NSOBJDIR_NAME) -- $(MCC_INCLUDE) $(CFLAGS) *.c *.cpp
endif
endif

ifndef NOSTDSTRIP
strip:
	$(STRIP) $(BINS)
endif


#
# --- Default Components Info ------------------------------------------------
#
# This section contains the info for the different components that used to be
# scattered throughout nsconfig.mk.  We are cleaning up these files and 
# dividing them up into:
# 
# nsconfig.mk for configuration specific defs.
# nsdefs.mk for default defs.
# components.mk for defs needed to pull components.

ifeq ($(INTERNAL_BUILD), 1)
include $(BUILD_ROOT)/internal_buildpaths.mk
else
include $(BUILD_ROOT)/buildpaths.mk
endif

NSCP_COMPDIR = $(BUILD_ROOT)/../components

##################################
# NSPR
#################################

NSPR_LIBNAMES = plc4 plds4 nspr4
ifdef NSPR_SOURCE_ROOT
  NSPR_LIBPATH = $(NSPR_SOURCE_ROOT)/dist/$(MOZ_OBJDIR_NAME)/lib
  NSPR_INCLUDE = $(NSPR_SOURCE_ROOT)/dist/$(MOZ_OBJDIR_NAME)/include
else
  NSPR_LIBPATH = $(NSPR_BUILD_DIR)/lib
  NSPR_INCLUDE = $(NSPR_BUILD_DIR)/include
endif

ifeq ($(ARCH), WINNT)
NSPRDLL_NAME = $(addprefix lib, $(NSPR_LIBNAMES))
#NSPRDLL_NAME = $(NSPR_LIBNAMES)
NSPROBJNAME = $(addsuffix .lib, $(NSPRDLL_NAME))
LIBNSPR = $(addprefix $(NSPR_LIBPATH)/, $(NSPROBJNAME))
PACKAGE_NSPR_DLLS = $(addprefix $(NSPR_LIBPATH)/, $(addsuffix .dll, $(NSPRDLL_NAME)))
else
NSPR_SOLIBS = $(addsuffix .$(DLL_SUFFIX),  $(addprefix lib, $(NSPR_LIBNAMES)))
NSPROBJNAME = $(addsuffix .a, $(addprefix lib, $(NSPR_LIBNAMES))
LIBNSPR = $(addprefix $(NSPR_LIBPATH)/, $(NSPR_SOLIBS))
NSPRLINK = -L$(NSPR_LIBPATH) $(addprefix -l, $(NSPR_LIBNAMES))
endif

#############################
# NSS
############################
ifdef SECURITY_SOURCE_ROOT
  SECURITY_LIBPATH = $(SECURITY_SOURCE_ROOT)/dist/$(MOZ_OBJDIR_NAME)/lib
  SECURITY_BINPATH = $(SECURITY_SOURCE_ROOT)/dist/$(MOZ_OBJDIR_NAME)/bin
  SECURITY_INCLUDE = $(SECURITY_SOURCE_ROOT)/dist/public/nss
else
  SECURITY_LIBPATH = $(SECURITY_BUILD_DIR)/lib
  SECURITY_BINPATH = $(SECURITY_BUILD_DIR)/bin
  SECURITY_INCLUDE = $(SECURITY_BUILD_DIR)/include
endif

SECURITY_LIBNAMES = smime3 ssl3 nss3 softokn3

# For NSS3, nssckbi shared library must be put in the same directory
# where secmod.db file is, rather than in the LD_LIBRARY_PATH 
SECURITY_SECMODDB_RUNTIME_LIBNAME = nssckbi

# freebl for all platforms is new for NSS 3.11
# there are some platform specific versions as well
FREEBL_LIBS = freebl3
ifeq ($(USE_64), 1)
 ifeq ($(ARCH), SOLARIS)
  FREEBL_LIBS = freebl_64fpu_3 freebl_64int_3
 endif
else  # USE_64
 ifeq ($(ARCH), SOLARIS)
  FREEBL_LIBS = freebl_32fpu_3 freebl_32int64_3 freebl_32int_3
 endif # SOLARIS
 ifeq ($(ARCH), HPUX)
  ifneq ($(NSOS_TEST1), ia64) # PA-RISC only
   FREEBL_LIBS = freebl_32fpu_3 freebl_32int_3
  endif
 endif # HPUX
endif # USE_64

# These files are only needed at runtime, not to link with
SECURITY_EXTRA_RUNTIME_LIBNAMES = $(FREEBL_LIBS)
# these shared libs need the corresponding .chk files at runtime
SECURITY_NEED_CHK = softokn3 $(FREEBL_LIBS)

ifeq ($(ARCH), WINNT)
SECURITYDLL_NAME = $(SECURITY_LIBNAMES)
SECURITYOBJNAME = $(addsuffix .lib, $(SECURITY_LIBNAMES))
LIBSECURITY = $(addprefix $(SECURITY_LIBPATH)/, $(SECURITYOBJNAME))
PACKAGE_SECURITY_DLLS = $(addprefix $(SECURITY_LIBPATH)/, $(addsuffix .dll, $(SECURITYDLL_NAME)))
# and the .chk files
PACKAGE_SECURITY_DLLS += $(addprefix $(SECURITY_LIBPATH)/, $(addsuffix .chk, $(SECURITY_NEED_CHK)))
else
SECURITY_SECMOD_SOLIB = $(addsuffix .$(DLL_SUFFIX),  $(addprefix lib, $(SECURITY_SECMODDB_RUNTIME_LIBNAME)))
SECURITY_SOLIBS = $(addsuffix .$(DLL_SUFFIX),  $(addprefix lib, $(SECURITY_LIBNAMES) $(SECURITY_EXTRA_RUNTIME_LIBNAMES)))
# and the .chk files
SECURITY_SOLIBS += $(addsuffix .chk,  $(addprefix lib, $(SECURITY_NEED_CHK)))
SECURITYOBJNAME = $(addsuffix .$(DLL_SUFFIX), $(addprefix lib, $(SECURITY_LIBNAMES)))
LIBSECURITY = $(addprefix $(SECURITY_LIBPATH)/, $(SECURITYOBJNAME))
SECURITYLINK = -L$(SECURITY_LIBPATH) $(addprefix -l, $(SECURITY_LIBNAMES))
endif

PKCS_TOOLDIR = $(NSCP_DISTDIR)/bin

###########################################
# ICU
##########################################

ICU_LIB_VERSION = 34
ifdef ICU_SOURCE_ROOT
  ICU_LIBPATH = $(ICU_SOURCE_ROOT)/built/lib
  ICU_BINPATH = $(ICU_SOURCE_ROOT)/built/bin
  ICU_INCLUDE = $(ICU_SOURCE_ROOT)/built/include
else
  ICU_LIBPATH = $(ICU_BUILD_DIR)/lib
  ICU_BINPATH = $(ICU_BUILD_DIR)/bin
  ICU_INCLUDE = $(ICU_BUILD_DIR)/include
endif

ifeq ($(BUILD_DEBUG), optimize)
ICU_DBG_SUF=
else
ICU_DBG_SUF=d
endif

ifeq ($(ARCH), WINNT)
	ICU_LIBNAMES = icuin$(ICU_DBG_SUF) icuuc$(ICU_DBG_SUF) icudata
	ICU_DLLNAMES = icuin$(ICU_LIB_VERSION)$(ICU_DBG_SUF) icuuc$(ICU_LIB_VERSION)$(ICU_DBG_SUF) icudt$(ICU_LIB_VERSION)l
	ICU_LIBS = $(addsuffix .lib, $(ICU_LIBNAMES))
	LIBICU = $(addprefix $(ICU_LIBPATH)/, $(ICU_LIBS))
	PACKAGE_ICU_DLLS = $(addprefix $(ICU_BINPATH)/, $(addsuffix .dll, $(ICU_DLLNAMES)))

else
	ICU_LIBNAMES =  icui18n icuuc icudata
	ICU_SOLIBS = $(addsuffix .$(DLL_SUFFIX).$(ICU_LIB_VERSION), $(addprefix lib, $(ICU_LIBNAMES)))
	LIBICU = $(addprefix $(ICU_LIBPATH)/, $(ICU_SOLIBS))
	ICULINK = -L$(ICU_LIBPATH) $(addprefix -l, $(ICU_LIBNAMES))
endif

###########################################
# SETUPUTIL
##########################################

ifdef SETUPUTIL_SOURCE_ROOT
  SETUPUTIL_LIBPATH = $(SETUPUTIL_SOURCE_ROOT)/built/package/$(PLATFORM_DEST)/lib
  SETUPUTIL_INCLUDE = $(SETUPUTIL_SOURCE_ROOT)/built/package/$(PLATFORM_DEST)/include
  SETUPUTIL_BIN     = $(SETUPUTIL_SOURCE_ROOT)/built/package/$(PLATFORM_DEST)/bin
else
  SETUPUTIL_LIBPATH = $(SETUPUTIL_BUILD_DIR)/lib
  SETUPUTIL_INCLUDE = $(SETUPUTIL_BUILD_DIR)/include
  SETUPUTIL_BIN     = $(SETUPUTIL_BUILD_DIR)/bin
endif

SETUPUTIL_TAR = setuputil.tar

SETUPUTIL_ABSFILE = $(ABS_ROOT)/components/$(SETUPUTIL_COMPNAME)/$(NSOBJDIR_NAME)/$(SETUPUTIL_FILE)

ifneq ($(ARCH), WINNT)
	SETUPUTIL_LIBNAMES = install
	SETUPUTIL_LIBS = $(addsuffix .a, $(addprefix lib, $(SETUPUTIL_LIBNAMES)))
	SETUPUTILOBJNAME = $(SETUPUTIL_LIBS)
	SETUPUTIL = $(addprefix $(SETUPUTIL_LIBPATH)/, $(SETUPUTIL_LIBS))
else
	SETUPUTIL_LIBNAMES = nssetup32_s
	SETUPUTIL_LIBS = $(addsuffix .lib, $(SETUPUTIL_LIBNAMES))
	SETUPUTILOBJNAME = $(SETUPUTIL_LIBS)
	SETUPUTIL = $(addprefix $(SETUPUTIL_LIBPATH)/, $(SETUPUTIL_LIBS))
endif

########################################
# ADMINUTIL
########################################

ADMINUTIL_LIB_VERSION=1.0
ifdef ADMINUTIL_SOURCE_ROOT
  ADMINUTIL_LIBPATH = $(ADMINUTIL_SOURCE_ROOT)/built/adminutil/$(PLATFORM_DEST)/lib
  ADMINUTIL_INCLUDE = $(ADMINUTIL_SOURCE_ROOT)/built/adminutil/$(PLATFORM_DEST)/include/adminutil-$(ADMINUTIL_LIB_VERSION)
else
  ADMINUTIL_LIBPATH = $(ADMINUTIL_BUILD_DIR)/lib
  ADMINUTIL_INCLUDE = $(ADMINUTIL_BUILD_DIR)/include/adminutil-$(ADMINUTIL_LIB_VERSION)
endif

ifeq ($(ARCH), WINNT)
	ADMINUTIL_LIBNAMES = libadmsslutil_s libadminutil
	ADMINUTIL_LIBS = $(addsuffix .lib,  $(ADMINUTIL_LIBNAMES))
	LIBADMINUTIL = $(addprefix $(ADMINUTIL_LIBPATH)/, $(ADMINUTIL_LIBS))
	ADMINUTILOBJNAME = $(ADMINUTIL_LIBNAMES)
else
	ADMINUTIL_LIBNAMES = admsslutil adminutil
	ADMINUTIL_SOLIB_NAMES = $(addsuffix $(DLL_PRESUF), $(addprefix lib, adminutil admsslutil))
	ADMINUTIL_LIBS = $(addsuffix .a, $(addprefix lib, $(ADMINUTIL_LIBNAMES)))
	ADMINUTIL_SOLIBS = $(addsuffix .$(DLL_SUFFIX).$(ADMINUTIL_LIB_VERSION), $(ADMINUTIL_SOLIB_NAMES))
	ADMINUTILOBJNAME = $(ADMINUTIL_SOLIBS)
	LIBADMINUTIL = $(addprefix $(ADMINUTIL_LIBPATH)/, $(ADMINUTIL_SOLIBS))
	ADMINUTILLINK = -L$(ADMINUTIL_LIBPATH) $(addprefix -l, $(ADMINUTIL_LIBNAMES))
endif

######################################
# LDAPSDK
#######################################

LDAP_LIB_VERSION = 60
ifdef LDAPSDK_SOURCE_ROOT
  LDAPSDK_LIBPATH = $(LDAPSDK_SOURCE_ROOT)/dist/lib
  LDAPSDK_INCLUDE = $(LDAPSDK_SOURCE_ROOT)/dist/public/ldap
  LDAPSDK_BINPATH = $(LDAPSDK_SOURCE_ROOT)/dist/bin
else
  LDAPSDK_LIBPATH = $(LDAPSDK_BUILD_DIR)/lib
  LDAPSDK_INCLUDE = $(LDAPSDK_BUILD_DIR)/include
  LDAPSDK_BINPATH = $(LDAPSDK_BUILD_DIR)/bin
endif

ifeq ($(ARCH), WINNT)
	LDAP_LIBNAMES = ldapssl32v$(LDAP_LIB_VERSION) ldap32v$(LDAP_LIB_VERSION) ldappr32v$(LDAP_LIB_VERSION)
	LDAPDLL_NAME = $(addprefix ns, $(LDAP_LIBNAMES))
	LDAPOBJNAME = $(addsuffix .lib, $(LDAPDLL_NAME))
else
	LDAP_SOLIB_NAMES = ssldap$(LDAP_LIB_VERSION)$(LDAP_DLL_PRESUF) ldap$(LDAP_LIB_VERSION)$(LDAP_DLL_PRESUF) prldap$(LDAP_LIB_VERSION)$(LDAP_DLL_PRESUF) 
	LDAP_LIBNAMES = ldap$(LDAP_LIB_VERSION)$(LDAP_DLL_PRESUF) lber$(LDAP_LIB_VERSION)$(LDAP_DLL_PRESUF)
	LDAP_SOLIBS = $(addsuffix .$(LDAP_DLL_SUFFIX), $(addprefix lib, $(LDAP_SOLIB_NAMES)))
	LDAPOBJNAME = $(addsuffix .a, $(addprefix lib, $(LDAP_LIBNAMES)))
	LDAPLINK = -L$(LDAPSDK_LIBPATH) $(addprefix -l, $(LDAP_SOLIB_NAMES))
endif

LIBLDAP = $(addprefix $(LDAPSDK_LIBPATH)/, $(LDAPOBJNAME))

#########################################
# MOD_ADMSERV, RESTARTD, NSS
#########################################
ifdef MOD_ADMSERV_SOURCE_ROOT
  MOD_ADMSERV_LIBPATH = $(MOD_ADMSERV_SOURCE_ROOT)/.libs
else
  MOD_ADMSERV_LIBPATH = $(MOD_ADMSERV_BUILD_DIR)/lib
endif
ifdef MOD_RESTARTD_SOURCE_ROOT
  MOD_RESTARTD_LIBPATH = $(MOD_RESTARTD_SOURCE_ROOT)/.libs
else
  MOD_RESTARTD_LIBPATH = $(MOD_RESTARTD_BUILD_DIR)/lib
endif
ifdef MOD_NSS_SOURCE_ROOT
  MOD_NSS_LIBPATH = $(MOD_NSS_SOURCE_ROOT)/.libs
  MOD_NSS_BINPATH = $(MOD_NSS_SOURCE_ROOT)
else
  MOD_NSS_LIBPATH = $(MOD_NSS_BUILD_DIR)/lib
  MOD_NSS_BINPATH = $(MOD_NSS_BUILD_DIR)/bin
endif

MOD_ADMSERV_LIBNAME = libmodadmserv.$(DLL_SUFFIX)
MOD_REATARTD_LIBNAME = libmodrestartd.$(DLL_SUFFIX)
MOD_NSS_LIBNAME = libmodnss.$(DLL_SUFFIX)

MOD_ADMSERV = $(addprefix $(MOD_ADMSERV_LIBPATH)/, $(MOD_ADMSERV_LIBNAME))
MOD_RESTARTD = $(addprefix $(MOD_RESTARTD_LIBPATH)/, $(MOD_REATARTD_LIBNAME))
MOD_NSS = $(addprefix $(MOD_NSS_LIBPATH)/, $(MOD_NSS_LIBNAME))

### The LDAP C SDK is now compiled with SASL support - this means
### that we will get undefined symbols when we link against the
### static LDAP libraries - we have to link with SASL to 
### resolve those symbols
ifeq ($(ARCH), Linux)
  ifeq ($(BUILD_ARCH), RHEL3)
    SASL_LIBPATH = /usr/kerberos/lib
    SASL_LINK = -L$(SASL_LIBPATH)
  else
# use default linker path
    SASL_LINK = 
  endif
  SASL_INCDIR = /usr/include/sasl
else
  ifdef SASL_SOURCE_ROOT
    SASL_LIBPATH = $(SASL_SOURCE_ROOT)/lib
    SASL_INCDIR = $(SASL_SOURCE_ROOT)/include/sasl
  else
    SASL_LIBPATH = $(SASL_BUILD_DIR)/lib
    SASL_INCDIR = $(SASL_BUILD_DIR)/include/sasl
  endif
  SASL_LINK = -L$(SASL_LIBPATH)
endif
SASL_INCLUDE = $(SASL_INCDIR)

ifeq ($(ARCH), WINNT)
  SASL_LIB_ROOT_NAME = sasl
  SASL_LINK = /LIBPATH:$(SASL_LIBPATH) lib$(SASL_LIB_ROOT_NAME).lib
  SASL_LIBS = lib$(SASL_LIB_ROOT_NAME).lib,lib$(SASL_LIB_ROOT_NAME).dll,saslDIGESTMD5.dll
else
  # for cyrus it's sasl2
  SASL_LIB_ROOT_NAME = sasl2
  SASL_LIBS = lib$(SASL_LIB_ROOT_NAME).a
  ifeq ($(ARCH), Linux)
# I don't think we need this anymore
    GSSAPI_LIBS=
#    GSSAPI_LIBS=-lgssapi_krb5
  endif
  ifeq ($(ARCH), SOLARIS)
    GSSAPI_LIBS=-lgss
  endif
  ifeq ($(ARCH), HPUX)
      GSSAPI_LIBS=-lgss
      ifeq ($(USE_64),1)
        GSSAPI_LIBS=-lgss
      endif
  endif

  SASL_LINK += -l$(SASL_LIB_ROOT_NAME) $(GSSAPI_LIBS)
endif

#########################################
# NMCSDK
#########################################

NMCJDK_JAR_VERSION = 10
NMCJDK_JARS = base.jar mcc$(NMCJDK_JAR_VERSION).jar mcc$(NMCJDK_JAR_VERSION)_en.jar nmclf$(NMCJDK_JAR_VERSION).jar nmclf$(NMCJDK_JAR_VERSION)_en.jar

#########################################
# LDAPJDK
#########################################

ifdef LDAPJDK_SOURCE_DIR
  LDAPJDK_DIR = $(LDAPJDK_SOURCE_DIR)/directory/java-sdk/dist/packages
else
ifdef LDAPJDK_BUILD_DIR
  LDAPJDK_DIR = $(LDAPJDK_BUILD_DIR)
else
  LDAPJDK_DIR = $(CLASS_DEST)
endif
endif

#########################################
# JSS - jar and shared library
#########################################

ifdef JSS_SOURCE_DIR
  JSS_JAR_DIR = $(JSS_SOURCE_DIR)/dist
  JSS_JAR_NAME = xpclass_dbg.jar
  ifeq ($(BUILD_DEBUG), optimize)
	JSS_JAR_NAME = xpclass.jar
  endif
  JSS_LIBPATH = $(JSS_SOURCE_DIR)/dist/$(MOZ_OBJDIR_NAME)/lib
else
ifdef INTERNAL_BUILD
  JSS_JAR_DIR = $(CLASS_DEST)
else
  JSS_JAR_DIR = $(JSS_BUILD_DIR)
endif
  JSS_LIBPATH = $(JSS_BUILD_DIR)/lib
  JSS_JAR_NAME = xpclass.jar
endif

ifdef CONSOLE_SOURCE_DIR
  CONSOLE_BASE_DIR = $(CONSOLE_SOURCE_DIR)/built/release/package
  CONSOLE_JAR_DIR = $(CONSOLE_BASE_DIR)/java
else
  CONSOLE_BASE_DIR = $(CLASS_DEST)
  CONSOLE_JAR_DIR = $(CLASS_DEST)
endif

ifdef ADMSERVCONSOLE_SOURCE_DIR
  ADMSERVCONSOLE_JAR_DIR = $(ADMSERVCONSOLE_SOURCE_DIR)/built/package
else
  ADMSERVCONSOLE_JAR_DIR = $(CLASS_DEST)
endif

ifdef ONLINEHELP_SOURCE_DIR
else
endif
